// @ts-nocheck
import React, { useEffect, useRef } from 'react'
import { Vector3, Euler } from 'three'

import api, { Transform } from '../store'

type PhantomProps = {
  id: string
}

const Phantom: React.FC<PhantomProps> = ({ id }) => {
  const ref = useRef<THREE.Mesh>(null)

  useEffect(() => {
    if (ref.current) {
      api.subscribe(
        (state: Transform | null) => {
          if (!state) {
            return
          }
          ref.current?.position.fromArray([
            state.position[0],
            state.position[1] + 0.25,
            state.position[2],
          ])
          ref.current?.rotation.fromArray(state.rotation)
        },
        (state) => state?.userTransforms?.[id],
      )
    }
  }, [ref.current])

  return (
    <group ref={ref}>
      <mesh scale={new Vector3(0.5, 0.5, 0.5)}>
        <sphereBufferGeometry />
        <meshStandardMaterial color="hotpink" />
        <meshBasicMaterial color="white" emmisive="white" opacity={0.8} transparent />
      </mesh>
      <mesh
        scale={new Vector3(0.15, 0.15, 0.15)}
        position={new Vector3(0, 0, -0.8)}
        rotation={new Euler(-Math.PI / 2, 0, 0)}
      >
        <coneBufferGeometry args={[1, 2, 4]} />
        <meshBasicMaterial color="yellow" emmisive="yellow" opacity={0.8} transparent />
      </mesh>
    </group>
  )
}

export default Phantom
