import React, { Suspense } from 'react'
import { useThree } from 'react-three-fiber'
import { Stats, Text } from '@react-three/drei'
import { Euler, Quaternion } from 'three'

import World from './models/World'
import Player from './Player'
import Lighting from './Lighting'
import Effects from './Effects'
import Controls from './Controls'
import Users from './Users'
import Computer from './models/Computer'
import { useEffect } from 'react'

const computerPositions = [
  {
    rotation: [0, 0.9340353012084961, 0, 0.35718077421188354],
    translation: [-26.65045738220215, 3.425341844558716, -113.49897766113281],
  },
  {
    rotation: [0, 0.9848144054412842, 0, 0.17361053824424744],
    translation: [-17.151742935180664, 3.4566614627838135, -108.55608367919922],
  },
  {
    rotation: [0, 0, 0, 0],
    translation: [-33.87189483642578, 3.452946424484253, -121.23444366455078],
  },
]

const Scene: React.FC = () => {
  // addAfterEffect(() => {
  //   console.log(gl.info.render);
  // });

  const { scene } = useThree()
  useEffect(() => {
    //if (scene) scene.overrideMaterial = new MeshBasicMaterial({ color: 'green' })
  }, [scene])

  return (
    <>
      <Stats />
      <Lighting />

      <Suspense fallback={null}>
        <World />
        <Player />

        <Text
          position={[-5.640829086303711, 13, -74.78675842285156]}
          color="white"
          fontSize={1.5}
          font="https://fonts.gstatic.com/s/raleway/v14/1Ptrg8zYS_SKggPNwK4vaqI.woff"
          anchorX="center"
          anchorY="middle"
        >
          ARTIFICIOS 2020
        </Text>

        <Text
          position={[-20.086780548095703, 10.144491195678711, -111.45488739013672]}
          quaternion={new Quaternion().fromArray([
            0,
            -0.9658790826797485,
            0,
            -0.258993536233902,
          ])}
          color="white"
          fontSize={0.8}
          font="https://fonts.gstatic.com/s/raleway/v14/1Ptrg8zYS_SKggPNwK4vaqI.woff"
          anchorX="center"
          anchorY="middle"
        >
          Aguyje Angirũ
        </Text>

        <Text
          position={[-31.250932693481445, 7.049933910369873, -90.546630859375]}
          quaternion={new Quaternion().fromArray([
            0,
            -0.9658790826797485,
            0,
            -0.258993536233902,
          ])}
          maxWidth={12}
          color="white"
          fontSize={0.4}
          font="https://fonts.gstatic.com/s/raleway/v14/1Ptrg8zYS_SKggPNwK4vaqI.woff"
          anchorX="center"
          anchorY="middle"
        >
          LOREM IPSUM DOLOR SIT AMET, CONSECTETUR ADIPISCING ELIT, SED DO EIUSMOD TEMPOR
          INCIDIDUNT UT LABORE ET DOLORE MAGNA ALIQUA. UT ENIM AD MINIM VENIAM, QUIS
          NOSTRUD EXERCITATION ULLAMCO LABORIS NISI UT ALIQUIP EX EA COMMODO CONSEQUAT.
        </Text>

        <Text
          position={[-33.941890716552734, 10.144491195678711, -126.15272521972656]}
          quaternion={new Quaternion().fromArray([
            0,
            -0.8729466199874878,
            0,
            -0.4878157675266266,
          ])}
          color="white"
          fontSize={0.6}
          font="https://fonts.gstatic.com/s/raleway/v14/1Ptrg8zYS_SKggPNwK4vaqI.woff"
          anchorX="center"
          anchorY="middle"
        >
          La Traicion de la Realidad
        </Text>

        <Text
          position={[-27.612287521362305, 10.144491195678711, -117.4875259399414]}
          quaternion={new Quaternion().fromArray([
            0,
            -0.9136363863945007,
            0,
            -0.40653231739997864,
          ])}
          color="white"
          fontSize={0.8}
          font="https://fonts.gstatic.com/s/raleway/v14/1Ptrg8zYS_SKggPNwK4vaqI.woff"
          anchorX="center"
          anchorY="middle"
        >
          No Requiem
        </Text>
      </Suspense>
      {computerPositions.map((computer, index) => (
        <Computer
          key={index}
          position={computer.translation}
          rotation={new Euler().setFromQuaternion(
            new Quaternion().fromArray(computer.rotation),
          )}
        />
      ))}
      <Users />
      <Effects />

      <Controls />
    </>
  )
}

export default Scene
